public inbox for intel-gfx@lists.freedesktop.org
 help / color / mirror / Atom feed
From: Maarten Lankhorst <maarten.lankhorst@linux.intel.com>
To: dri-devel@lists.freedesktop.org
Cc: intel-gfx@lists.freedesktop.org
Subject: [PATCH v2 2/7] drm/atomic: Make add_affected_connectors look at crtc_state.
Date: Tue, 10 Jan 2017 11:21:33 +0100	[thread overview]
Message-ID: <1484043698-6703-3-git-send-email-maarten.lankhorst@linux.intel.com> (raw)
In-Reply-To: <1484043698-6703-1-git-send-email-maarten.lankhorst@linux.intel.com>

This kills another dereference of connector->state. connector_mask
holds all unchanged connectors at least and any changed connectors
are already in state anyway.

Signed-off-by: Maarten Lankhorst <maarten.lankhorst@linux.intel.com>
---
 drivers/gpu/drm/drm_atomic.c | 11 ++++++++---
 1 file changed, 8 insertions(+), 3 deletions(-)

diff --git a/drivers/gpu/drm/drm_atomic.c b/drivers/gpu/drm/drm_atomic.c
index 1c1cbf436717..18cdf2c956c6 100644
--- a/drivers/gpu/drm/drm_atomic.c
+++ b/drivers/gpu/drm/drm_atomic.c
@@ -1419,8 +1419,13 @@ drm_atomic_add_affected_connectors(struct drm_atomic_state *state,
 	struct drm_connector *connector;
 	struct drm_connector_state *conn_state;
 	struct drm_connector_list_iter conn_iter;
+	struct drm_crtc_state *crtc_state;
 	int ret;
 
+	crtc_state = drm_atomic_get_crtc_state(state, crtc);
+	if (IS_ERR(crtc_state))
+		return PTR_ERR(crtc_state);
+
 	ret = drm_modeset_lock(&config->connection_mutex, state->acquire_ctx);
 	if (ret)
 		return ret;
@@ -1429,12 +1434,12 @@ drm_atomic_add_affected_connectors(struct drm_atomic_state *state,
 			 crtc->base.id, crtc->name, state);
 
 	/*
 	 * Changed connectors are already in @state, so only need to look at the
 	 * current configuration.
 	 */
 	drm_connector_list_iter_get(state->dev, &conn_iter);
 	drm_for_each_connector_iter(connector, &conn_iter) {
-		if (connector->state->crtc != crtc)
+		if (!(crtc_state->connector_mask & (1 << drm_connector_index(connector))))
 			continue;
 
 		conn_state = drm_atomic_get_connector_state(state, connector);
@@ -1429,12 +1434,12 @@ drm_atomic_add_affected_connectors(struct drm_atomic_state *state,
 
 	/*
-	 * Changed connectors are already in @state, so only need to look at the
-	 * current configuration.
+	 * Changed connectors are already in @state, so only need to look
+	 * at the connector_mask in crtc_state.
 	 */
 	drm_connector_list_iter_get(state->dev, &conn_iter);
-- 
2.7.4

_______________________________________________
dri-devel mailing list
dri-devel@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/dri-devel

  parent reply	other threads:[~2017-01-10 10:21 UTC|newest]

Thread overview: 13+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2017-01-10 10:21 [PATCH v2 0/7] drm/atomic: Add accessor macros for all atomic state Maarten Lankhorst
2017-01-10 10:21 ` [PATCH v2 1/7] drm/atomic: Add new iterators over all state Maarten Lankhorst
2017-01-10 13:46   ` [PATCH v2.1 1/7] drm/atomic: Add new iterators over all state, v3 Maarten Lankhorst
2017-01-15 19:56     ` Laurent Pinchart
2017-01-16  9:26       ` Maarten Lankhorst
2017-01-10 10:21 ` Maarten Lankhorst [this message]
2017-01-10 10:21 ` [PATCH v2 3/7] drm/atomic: Use new atomic iterator macros Maarten Lankhorst
2017-01-10 10:21 ` [PATCH v2 4/7] drm/atomic: Fix atomic helpers to use the new " Maarten Lankhorst
2017-01-10 10:21 ` [PATCH v2 5/7] drm/atomic: Add macros to access existing old/new state Maarten Lankhorst
2017-01-10 10:21 ` [PATCH v2 6/7] drm/atomic: Convert get_existing_state callers to get_old/new_state Maarten Lankhorst
2017-01-12  9:27   ` [PATCH v2.1 6/7] drm/atomic: Convert get_existing_state callers to get_old/new_state, v2 Maarten Lankhorst
2017-01-10 10:21 ` [PATCH v2 7/7] drm/blend: Use new atomic iterator macros Maarten Lankhorst
2017-01-10 12:23 ` ✗ Fi.CI.BAT: warning for drm/atomic: Add accessor macros for all atomic state Patchwork

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=1484043698-6703-3-git-send-email-maarten.lankhorst@linux.intel.com \
    --to=maarten.lankhorst@linux.intel.com \
    --cc=dri-devel@lists.freedesktop.org \
    --cc=intel-gfx@lists.freedesktop.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox